pub struct DeviceNames {
pub default_names: Option<Vec<String>>,
pub name: Option<String>,
pub nicknames: Option<Vec<String>>,
}Expand description
Identifiers used to describe the device.
This type is not used in any activity, and only used as part of another schema.
Fields
default_names: Option<Vec<String>>List of names provided by the manufacturer rather than the user, such as serial numbers, SKUs, etc.
name: Option<String>Primary name of the device, generally provided by the user.
nicknames: Option<Vec<String>>Additional names provided by the user for the device.