pub struct ReportStateAndNotificationResponse {
pub request_id: Option<String>,
}Expand description
Response type for the ReportStateAndNotification call.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- report state and notification devices (response)
Fields
request_id: Option<String>Request ID copied from ReportStateAndNotificationRequest.