pub struct SyncRequest {
pub agent_user_id: Option<String>,
pub request_id: Option<String>,
}Expand description
Request type for the Sync call.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sync devices (request)
Fields
agent_user_id: Option<String>Required. Third-party user ID.
request_id: Option<String>Request ID used for debugging.