pub struct SyncResponse {
pub payload: Option<SyncResponsePayload>,
pub request_id: Option<String>,
}Expand description
Response type for the Sync call. This should follow the same format as the Google smart home action.devices.SYNC response. Example: json { "requestId": "ff36a3cc-ec34-11e6-b1a0-64510650abcf", "payload": { "agentUserId": "1836.15267389", "devices": [{ "id": "123", "type": "action.devices.types.OUTLET", "traits": [ "action.devices.traits.OnOff" ], "name": { "defaultNames": ["My Outlet 1234"], "name": "Night light", "nicknames": ["wall plug"] }, "willReportState": false, "deviceInfo": { "manufacturer": "lights-out-inc", "model": "hs1234", "hwVersion": "3.2", "swVersion": "11.4" }, "customData": { "fooValue": 74, "barValue": true, "bazValue": "foo" } }] } }
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sync devices (response)
Fields
payload: Option<SyncResponsePayload>Devices associated with the third-party user.
request_id: Option<String>Request ID used for debugging. Copied from the request.